Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(663)

Unified Diff: src/compiler/pipeline.cc

Issue 2287313002: [turbofan] Fix confusing phase name. (Closed)
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/pipeline.cc
diff --git a/src/compiler/pipeline.cc b/src/compiler/pipeline.cc
index 584d2ff417802e6ce04433fbd6d45f3938293d9b..bdbfccd01d8ba8d1a3afcd7834f3bfcf718868e7 100644
--- a/src/compiler/pipeline.cc
+++ b/src/compiler/pipeline.cc
@@ -1074,14 +1074,13 @@ struct EffectControlLinearizationPhase {
};
// The store-store elimination greatly benefits from doing a common operator
// reducer just before it, to eliminate conditional deopts with a constant
// condition.
struct DeadCodeEliminationPhase {
- static const char* phase_name() { return "common operator reducer"; }
+ static const char* phase_name() { return "dead code elimination"; }
void Run(PipelineData* data, Zone* temp_zone) {
- // Run the common operator reducer.
JSGraphReducer graph_reducer(data->jsgraph(), temp_zone);
DeadCodeElimination dead_code_elimination(&graph_reducer, data->graph(),
data->common());
@@ -1594,7 +1593,7 @@ bool PipelineImpl::OptimizeGraph(Linkage* linkage) {
RunPrintAndVerify("Effect and control linearized", true);
Run<DeadCodeEliminationPhase>();
- RunPrintAndVerify("Common operator reducer", true);
+ RunPrintAndVerify("Dead code elimination", true);
if (FLAG_turbo_store_elimination) {
Run<StoreStoreEliminationPhase>();
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -1074,14 +1074,13 @@ struct EffectControlLinearizationPhase {
};
// The store-store elimination greatly benefits from doing a common operator
-// reducer just before it, to eliminate conditional deopts with a constant
-// condition.
+// reducer and dead code elimination just before it, to eliminate conditional
+// deopts with a constant condition.
struct DeadCodeEliminationPhase {

Powered by Google App Engine
This is Rietveld 408576698